@@ -9,9 +9,12 @@ use oura::sources::n2c::Config as N2CConfig;
 use oura::sources::n2n::Config as N2NConfig;
 use serde_derive::Deserialize;
 
-#[cfg(kafkasink)]
+#[cfg(feature = "kafkasink")]
 use oura::sinks::kafka::Config as KafkaConfig;
 
+#[cfg(feature = "elasticsink")]
+use oura::sinks::elastic::Config as ElasticConfig;
+
 use crate::Error;
 
 #[derive(Debug, Deserialize)]
@@ -35,8 +38,11 @@ impl SourceConfig for Source {
 enum Sink {
     Terminal(TerminalConfig),
 
-    #[cfg(kafkasink)]
+    #[cfg(feature = "kafkasink")]
     Kafka(KafkaConfig),
+    
+    #[cfg(feature = "elasticsink")]
+    Elastic(ElasticConfig),
 }
 
 impl SinkConfig for Sink {
@@ -44,8 +50,11 @@ impl SinkConfig for Sink {
         match self {
             Sink::Terminal(c) => c.bootstrap(input),
 
-            #[cfg(kafkasink)]
+            #[cfg(feature = "kafkasink")]
             Sink::Kafka(c) => c.bootstrap(input),
+            
+            #[cfg(feature = "elasticsink")]
+            Sink::Elastic(c) => c.bootstrap(input),
         }
     }
 }
